# Generated by Django 5.0 on 2024-03-01 17:24

import django.db.models.deletion
import mptt.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("flex_menu", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="menuitem",
            name="label_en",
            field=models.CharField(
                help_text="Display name on the website.",
                max_length=50,
                null=True,
                verbose_name="label",
            ),
        ),
        migrations.AddField(
            model_name="menuitem",
            name="label_fa",
            field=models.CharField(
                help_text="Display name on the website.",
                max_length=50,
                null=True,
                verbose_name="label",
            ),
        ),
        migrations.AlterField(
            model_name="menu",
            name="language",
            field=models.CharField(
                choices=[("en", "English"), ("fa", "Farsi")], default="en", max_length=5
            ),
        ),
        migrations.AlterField(
            model_name="menuitem",
            name="language",
            field=models.CharField(
                choices=[("en", "English"), ("fa", "Farsi")], default="en", max_length=5
            ),
        ),
        migrations.AlterField(
            model_name="menuitem",
            name="parent",
            field=mptt.fields.TreeForeignKey(
                blank=True,
                limit_choices_to={"level": 0},
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="children",
                to="flex_menu.menuitem",
                verbose_name="parent",
            ),
        ),
    ]
