<a class="nav-link{% if extra_classes %} {{ extra_classes }}{% endif %}" role="button" {% if extra %}{{ extra|safe }}{% endif %} href="{{ href }}" {% if no_reload %}{{ template_settings.a_navigation_htmx }}{% endif %}>
    {{ content }}
</a>
